package com.fs.live.service.impl;

import java.util.Collections;
import java.util.List;
import com.fs.common.utils.DateUtils;
import com.fs.live.param.CouponPO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.fs.live.mapper.LiveCouponUserMapper;
import com.fs.live.domain.LiveCouponUser;
import com.fs.live.service.ILiveCouponUserService;

/**
 * 优惠券发放记录Service业务层处理
 *
 * @author fs
 * @date 2025-09-30
 */
@Service
public class LiveCouponUserServiceImpl implements ILiveCouponUserService
{
    @Autowired
    private LiveCouponUserMapper liveCouponUserMapper;

    /**
     * 查询优惠券发放记录
     *
     * @param id 优惠券发放记录ID
     * @return 优惠券发放记录
     */
    @Override
    public LiveCouponUser selectLiveCouponUserById(Long id)
    {
        return liveCouponUserMapper.selectLiveCouponUserById(id);
    }

    /**
     * 查询优惠券发放记录列表
     *
     * @param liveCouponUser 优惠券发放记录
     * @return 优惠券发放记录
     */
    @Override
    public List<LiveCouponUser> selectLiveCouponUserList(LiveCouponUser liveCouponUser)
    {
        return liveCouponUserMapper.selectLiveCouponUserList(liveCouponUser);
    }

    /**
     * 新增优惠券发放记录
     *
     * @param liveCouponUser 优惠券发放记录
     * @return 结果
     */
    @Override
    public int insertLiveCouponUser(LiveCouponUser liveCouponUser)
    {
        liveCouponUser.setCreateTime(DateUtils.getNowDate());
        return liveCouponUserMapper.insertLiveCouponUser(liveCouponUser);
    }

    /**
     * 修改优惠券发放记录
     *
     * @param liveCouponUser 优惠券发放记录
     * @return 结果
     */
    @Override
    public int updateLiveCouponUser(LiveCouponUser liveCouponUser)
    {
        liveCouponUser.setUpdateTime(DateUtils.getNowDate());
        return liveCouponUserMapper.updateLiveCouponUser(liveCouponUser);
    }

    /**
     * 批量删除优惠券发放记录
     *
     * @param ids 需要删除的优惠券发放记录ID
     * @return 结果
     */
    @Override
    public int deleteLiveCouponUserByIds(Long[] ids)
    {
        return liveCouponUserMapper.deleteLiveCouponUserByIds(ids);
    }

    /**
     * 删除优惠券发放记录信息
     *
     * @param id 优惠券发放记录ID
     * @return 结果
     */
    @Override
    public int deleteLiveCouponUserById(Long id)
    {
        return liveCouponUserMapper.deleteLiveCouponUserById(id);
    }

    @Override
    public List<LiveCouponUser> selectLiveCouponUserByCouponPO(CouponPO coupon) {
        return liveCouponUserMapper.selectLiveCouponUserByCouponPO(coupon);
    }

    @Override
    public List<LiveCouponUser> curCoupon(CouponPO coupon) {
        return liveCouponUserMapper.curCoupon(coupon);
    }
}
