package com.fs.live.controller;

import java.util.List;

import com.fs.common.utils.ParseUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.fs.common.annotation.Log;
import com.fs.common.core.controller.BaseController;
import com.fs.common.core.domain.AjaxResult;
import com.fs.common.enums.BusinessType;
import com.fs.live.domain.LiveCouponUser;
import com.fs.live.service.ILiveCouponUserService;
import com.fs.common.utils.poi.ExcelUtil;
import com.fs.common.core.page.TableDataInfo;

/**
 * 优惠券发放记录Controller
 *
 * @author fs
 * @date 2025-09-30
 */
@RestController
@RequestMapping("/live/coupon/user")
public class LiveCouponUserController extends BaseController
{
    @Autowired
    private ILiveCouponUserService liveCouponUserService;

    /**
     * 查询优惠券发放记录列表
     */
    @PreAuthorize("@ss.hasPermi('live:issue:list')")
    @GetMapping("/list")
    public TableDataInfo list(LiveCouponUser liveCouponUser)
    {
        startPage();
        List<LiveCouponUser> list = liveCouponUserService.selectLiveCouponUserList(liveCouponUser);
        return getDataTable(list);
    }

    /**
     * 导出优惠券发放记录列表
     */
    @PreAuthorize("@ss.hasPermi('live:issue:export')")
    @Log(title = "优惠券发放记录", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(LiveCouponUser liveCouponUser)
    {
        List<LiveCouponUser> list = liveCouponUserService.selectLiveCouponUserList(liveCouponUser);
        ExcelUtil<LiveCouponUser> util = new ExcelUtil<LiveCouponUser>(LiveCouponUser.class);
        return util.exportExcel(list, "user");
    }

    /**
     * 获取优惠券发放记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('live:issue:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return AjaxResult.success(liveCouponUserService.selectLiveCouponUserById(id));
    }

    /**
     * 新增优惠券发放记录
     */
    @PreAuthorize("@ss.hasPermi('live:issue:add')")
    @Log(title = "优惠券发放记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody LiveCouponUser liveCouponUser)
    {
        return toAjax(liveCouponUserService.insertLiveCouponUser(liveCouponUser));
    }

    /**
     * 修改优惠券发放记录
     */
    @PreAuthorize("@ss.hasPermi('live:issue:edit')")
    @Log(title = "优惠券发放记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody LiveCouponUser liveCouponUser)
    {
        return toAjax(liveCouponUserService.updateLiveCouponUser(liveCouponUser));
    }

    /**
     * 删除优惠券发放记录
     */
    @PreAuthorize("@ss.hasPermi('live:issue:remove')")
    @Log(title = "优惠券发放记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(liveCouponUserService.deleteLiveCouponUserByIds(ids));
    }
}
